diff --git a/src/metabase/db/env.clj b/src/metabase/db/env.clj
index ae541a769f3efd4d310e8a00f540bc2c044e9b2d..0a775c47bd36e2eb1a2f1a195a23d18b19404818 100644
--- a/src/metabase/db/env.clj
+++ b/src/metabase/db/env.clj
@@ -1,7 +1,7 @@
 (ns metabase.db.env
   "Logic related to fetching and working with the connection details for the application database. These are provided by
   environment variables -- either as a single JDBC connection URL string (`MB_DB_CONNECTION_URI`) or as broken-out
-  enviornment variables e.g. `MB_DB_TYPE`, `MB_DB_HOST`, etc. `MB_DB_CONNECTION_URI` is used preferentially if both
+  environment variables e.g. `MB_DB_TYPE`, `MB_DB_HOST`, etc. `MB_DB_CONNECTION_URI` is used preferentially if both
   are specified.
 
   There are three ways you can specify application JDBC connection information for Metabase:
@@ -92,7 +92,7 @@
     (mdb.data-source/broken-out-details->DataSource db-type (broken-out-details db-type env-vars))))
 
 
 ;;;; exports: [[db-type]], [[db-file]], and [[data-source]] created using enviornment variables.
 
 (def ^:private env
   {:mb-db-type           (config/config-kw :mb-db-type)
@@ -92,7 +92,7 @@
 
 
-;;;; exports: [[db-type]], [[db-file]], and [[data-source]] created using enviornment variables.
+;;;; exports: [[db-type]], [[db-file]], and [[data-source]] created using environment variables.
 
 (def ^:private env